Module beamlit.models.pending_invitation_workspace_details
==========================================================

Classes
-------

`PendingInvitationWorkspaceDetails(emails: beamlit.types.Unset | list[typing.Any] = <beamlit.types.Unset object>, user_number: beamlit.types.Unset | float = <beamlit.types.Unset object>)`
:   Workspace details
    
    Attributes:
        emails (Union[Unset, list[Any]]): List of user emails in the workspace
        user_number (Union[Unset, float]): Number of users in the workspace
    
    Method generated by attrs for class PendingInvitationWorkspaceDetails.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `emails: beamlit.types.Unset | list[typing.Any]`
    :

    `user_number: beamlit.types.Unset | float`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :